"""Ferda plugins configuration."""
from collections import OrderedDict
from dataclasses import dataclass
from typing import Callable, Optional

from ferda.models import User


@dataclass
class PluginConfig(object):
    """
    Ferda plugin configuration.

    Attributes:
        name: Name of the plugin. This name is shown in plugins main menu.
        url: Root url of the plugin.
            This url is used as target in plugins main menu.
            Usually, this value is computed by reverse_lazy method.
        icon: Name of icon from Material Design icon list.
        access: Function that takes user as its first argument and
            returns whether that user can access the plugin.
    """

    name: str
    url: str
    icon: Optional[str] = None
    access: Callable[[User], bool] = (lambda x: True)


def register(app_name: str, config: PluginConfig) -> None:
    """Register ferda plugin."""
    CONFIG[app_name] = config


CONFIG = OrderedDict()  # type: OrderedDict[str, PluginConfig]
