"""Registry contact REST API views."""
from asgiref.sync import sync_to_async
from ninja import Router
from regal import ContactId

from ferda.api import Error, check_permissions
from ferda.backend import STATEMENTOR
from ferda.constants import LogReferenceType
from ferda.registry.record_statement import get_object_statement_pdf

router = Router(tags=['registry', 'contact'])


@router.get('/record_statement/{contact_id}/', url_name='get_contact_record_statement_pdf', response={
    200: bytes,
    404: Error,
})
async def get_contact_record_statement_pdf(request, contact_id: ContactId):
    """Get verified record statement of the contact."""
    await sync_to_async(check_permissions)(request, permissions=['ferda.can_view_registry'])
    return await get_object_statement_pdf(
        request, ContactId(contact_id), LogReferenceType.CONTACT, STATEMENTOR.get_contact_statement
    )
